@@ -47,7 +47,7 @@ Q_OBJECT
     int fieldAt(const QPoint& p);
 public:
     explicit SeaView(QWidget* parent);
-    ~SeaView();
+    ~SeaView() override;
     
     void setDelegate(Delegate* c);
     void cancelPreview();
@@ -71,7 +71,7 @@ protected:
     void resizeEvent(QResizeEvent*) override;
     
     QSize tileSize() const;
-public slots:
+public Q_SLOTS:
     void refresh();
 };
 
